==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/AndroidManagedAppRegistration.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Arrays;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.complex.MobileAppIdentifier;
import odata.msgraph.client.beta.enums.ManagedAppFlaggedReason;


/**
 * <i>“The ManagedAppRegistration resource represents the details of an app, with
 * management capability, used by a member of the organization.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "patchVersion"})
@JsonInclude(Include.NON_NULL)
public class AndroidManagedAppRegistration extends ManagedAppRegistration implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.androidManagedAppRegistration";
    }

    @JsonProperty("patchVersion")
    protected String patchVersion;

    protected AndroidManagedAppRegistration() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAndroidManagedAppRegistration() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private OffsetDateTime createdDateTime;
        private OffsetDateTime lastSyncDateTime;
        private String applicationVersion;
        private String managementSdkVersion;
        private String platformVersion;
        private String deviceType;
        private String deviceTag;
        private String deviceName;
        private String managedDeviceId;
        private String azureADDeviceId;
        private String deviceModel;
        private String deviceManufacturer;
        private List<ManagedAppFlaggedReason> flaggedReasons;
        private String flaggedReasonsNextLink;
        private String userId;
        private MobileAppIdentifier appIdentifier;
        private String version;
        private String patchVersion;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder createdDateTime(OffsetDateTime createdDateTime) {
            this.createdDateTime = createdDateTime;
            this.changedFields = changedFields.add("createdDateTime");
            return this;
        }

        public Builder lastSyncDateTime(OffsetDateTime lastSyncDateTime) {
            this.lastSyncDateTime = lastSyncDateTime;
            this.changedFields = changedFields.add("lastSyncDateTime");
            return this;
        }

        public Builder applicationVersion(String applicationVersion) {
            this.applicationVersion = applicationVersion;
            this.changedFields = changedFields.add("applicationVersion");
            return this;
        }

        public Builder managementSdkVersion(String managementSdkVersion) {
            this.managementSdkVersion = managementSdkVersion;
            this.changedFields = changedFields.add("managementSdkVersion");
            return this;
        }

        public Builder platformVersion(String platformVersion) {
            this.platformVersion = platformVersion;
            this.changedFields = changedFields.add("platformVersion");
            return this;
        }

        public Builder deviceType(String deviceType) {
            this.deviceType = deviceType;
            this.changedFields = changedFields.add("deviceType");
            return this;
        }

        public Builder deviceTag(String deviceTag) {
            this.deviceTag = deviceTag;
            this.changedFields = changedFields.add("deviceTag");
            return this;
        }

        public Builder deviceName(String deviceName) {
            this.deviceName = deviceName;
            this.changedFields = changedFields.add("deviceName");
            return this;
        }

        public Builder managedDeviceId(String managedDeviceId) {
            this.managedDeviceId = managedDeviceId;
            this.changedFields = changedFields.add("managedDeviceId");
            return this;
        }

        public Builder azureADDeviceId(String azureADDeviceId) {
            this.azureADDeviceId = azureADDeviceId;
            this.changedFields = changedFields.add("azureADDeviceId");
            return this;
        }

        public Builder deviceModel(String deviceModel) {
            this.deviceModel = deviceModel;
            this.changedFields = changedFields.add("deviceModel");
            return this;
        }

        public Builder deviceManufacturer(String deviceManufacturer) {
            this.deviceManufacturer = deviceManufacturer;
            this.changedFields = changedFields.add("deviceManufacturer");
            return this;
        }

        public Builder flaggedReasons(List<ManagedAppFlaggedReason> flaggedReasons) {
            this.flaggedReasons = flaggedReasons;
            this.changedFields = changedFields.add("flaggedReasons");
            return this;
        }

        public Builder flaggedReasons(ManagedAppFlaggedReason... flaggedReasons) {
            return flaggedReasons(Arrays.asList(flaggedReasons));
        }

        public Builder flaggedReasonsNextLink(String flaggedReasonsNextLink) {
            this.flaggedReasonsNextLink = flaggedReasonsNextLink;
            this.changedFields = changedFields.add("flaggedReasons");
            return this;
        }

        public Builder userId(String userId) {
            this.userId = userId;
            this.changedFields = changedFields.add("userId");
            return this;
        }

        public Builder appIdentifier(MobileAppIdentifier appIdentifier) {
            this.appIdentifier = appIdentifier;
            this.changedFields = changedFields.add("appIdentifier");
            return this;
        }

        public Builder version(String version) {
            this.version = version;
            this.changedFields = changedFields.add("version");
            return this;
        }

        /**
         * <i>“The patch version for the current android app registration”</i>
         * 
         * @param patchVersion
         *            value of {@code patchVersion} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder patchVersion(String patchVersion) {
            this.patchVersion = patchVersion;
            this.changedFields = changedFields.add("patchVersion");
            return this;
        }

        public AndroidManagedAppRegistration build() {
            AndroidManagedAppRegistration _x = new AndroidManagedAppRegistration();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.androidManagedAppRegistration";
            _x.id = id;
            _x.createdDateTime = createdDateTime;
            _x.lastSyncDateTime = lastSyncDateTime;
            _x.applicationVersion = applicationVersion;
            _x.managementSdkVersion = managementSdkVersion;
            _x.platformVersion = platformVersion;
            _x.deviceType = deviceType;
            _x.deviceTag = deviceTag;
            _x.deviceName = deviceName;
            _x.managedDeviceId = managedDeviceId;
            _x.azureADDeviceId = azureADDeviceId;
            _x.deviceModel = deviceModel;
            _x.deviceManufacturer = deviceManufacturer;
            _x.flaggedReasons = flaggedReasons;
            _x.flaggedReasonsNextLink = flaggedReasonsNextLink;
            _x.userId = userId;
            _x.appIdentifier = appIdentifier;
            _x.version = version;
            _x.patchVersion = patchVersion;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    /**
     * <i>“The patch version for the current android app registration”</i>
     * 
     * @return property patchVersion
     */
    @Property(name="patchVersion")
    @JsonIgnore
    public Optional<String> getPatchVersion() {
        return Optional.ofNullable(patchVersion);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code patchVersion}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“The patch version for the current android app registration”</i>
     * 
     * @param patchVersion
     *            new value of {@code patchVersion} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code patchVersion} field changed
     */
    public AndroidManagedAppRegistration withPatchVersion(String patchVersion) {
        AndroidManagedAppRegistration _x = _copy();
        _x.changedFields = changedFields.add("patchVersion");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.androidManagedAppRegistration");
        _x.patchVersion = patchVersion;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AndroidManagedAppRegistration patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        AndroidManagedAppRegistration _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AndroidManagedAppRegistration put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        AndroidManagedAppRegistration _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private AndroidManagedAppRegistration _copy() {
        AndroidManagedAppRegistration _x = new AndroidManagedAppRegistration();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.createdDateTime = createdDateTime;
        _x.lastSyncDateTime = lastSyncDateTime;
        _x.applicationVersion = applicationVersion;
        _x.managementSdkVersion = managementSdkVersion;
        _x.platformVersion = platformVersion;
        _x.deviceType = deviceType;
        _x.deviceTag = deviceTag;
        _x.deviceName = deviceName;
        _x.managedDeviceId = managedDeviceId;
        _x.azureADDeviceId = azureADDeviceId;
        _x.deviceModel = deviceModel;
        _x.deviceManufacturer = deviceManufacturer;
        _x.flaggedReasons = flaggedReasons;
        _x.userId = userId;
        _x.appIdentifier = appIdentifier;
        _x.version = version;
        _x.patchVersion = patchVersion;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AndroidManagedAppRegistration[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("createdDateTime=");
        b.append(this.createdDateTime);
        b.append(", ");
        b.append("lastSyncDateTime=");
        b.append(this.lastSyncDateTime);
        b.append(", ");
        b.append("applicationVersion=");
        b.append(this.applicationVersion);
        b.append(", ");
        b.append("managementSdkVersion=");
        b.append(this.managementSdkVersion);
        b.append(", ");
        b.append("platformVersion=");
        b.append(this.platformVersion);
        b.append(", ");
        b.append("deviceType=");
        b.append(this.deviceType);
        b.append(", ");
        b.append("deviceTag=");
        b.append(this.deviceTag);
        b.append(", ");
        b.append("deviceName=");
        b.append(this.deviceName);
        b.append(", ");
        b.append("managedDeviceId=");
        b.append(this.managedDeviceId);
        b.append(", ");
        b.append("azureADDeviceId=");
        b.append(this.azureADDeviceId);
        b.append(", ");
        b.append("deviceModel=");
        b.append(this.deviceModel);
        b.append(", ");
        b.append("deviceManufacturer=");
        b.append(this.deviceManufacturer);
        b.append(", ");
        b.append("flaggedReasons=");
        b.append(this.flaggedReasons);
        b.append(", ");
        b.append("userId=");
        b.append(this.userId);
        b.append(", ");
        b.append("appIdentifier=");
        b.append(this.appIdentifier);
        b.append(", ");
        b.append("version=");
        b.append(this.version);
        b.append(", ");
        b.append("patchVersion=");
        b.append(this.patchVersion);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/AndroidManagedAppRegistration.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Arrays;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.complex.MobileAppIdentifier;
import odata.msgraph.client.beta.enums.ManagedAppFlaggedReason;


/**
 * <i>“The ManagedAppRegistration resource represents the details of an app, with
 * management capability, used by a member of the organization.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "patchVersion"})
@JsonInclude(Include.NON_NULL)
public class AndroidManagedAppRegistration extends ManagedAppRegistration implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.androidManagedAppRegistration";
    }

    @JsonProperty("patchVersion")
    protected String patchVersion;

    protected AndroidManagedAppRegistration() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAndroidManagedAppRegistration() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private MobileAppIdentifier appIdentifier;
        private String applicationVersion;
        private String azureADDeviceId;
        private OffsetDateTime createdDateTime;
        private String deviceManufacturer;
        private String deviceModel;
        private String deviceName;
        private String deviceTag;
        private String deviceType;
        private List<ManagedAppFlaggedReason> flaggedReasons;
        private String flaggedReasonsNextLink;
        private OffsetDateTime lastSyncDateTime;
        private String managedDeviceId;
        private String managementSdkVersion;
        private String platformVersion;
        private String userId;
        private String version;
        private List<ManagedAppPolicy> appliedPolicies;
        private List<ManagedAppPolicy> intendedPolicies;
        private List<ManagedAppOperation> operations;
        private String patchVersion;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder appIdentifier(MobileAppIdentifier appIdentifier) {
            this.appIdentifier = appIdentifier;
            this.changedFields = changedFields.add("appIdentifier");
            return this;
        }

        public Builder applicationVersion(String applicationVersion) {
            this.applicationVersion = applicationVersion;
            this.changedFields = changedFields.add("applicationVersion");
            return this;
        }

        public Builder azureADDeviceId(String azureADDeviceId) {
            this.azureADDeviceId = azureADDeviceId;
            this.changedFields = changedFields.add("azureADDeviceId");
            return this;
        }

        public Builder createdDateTime(OffsetDateTime createdDateTime) {
            this.createdDateTime = createdDateTime;
            this.changedFields = changedFields.add("createdDateTime");
            return this;
        }

        public Builder deviceManufacturer(String deviceManufacturer) {
            this.deviceManufacturer = deviceManufacturer;
            this.changedFields = changedFields.add("deviceManufacturer");
            return this;
        }

        public Builder deviceModel(String deviceModel) {
            this.deviceModel = deviceModel;
            this.changedFields = changedFields.add("deviceModel");
            return this;
        }

        public Builder deviceName(String deviceName) {
            this.deviceName = deviceName;
            this.changedFields = changedFields.add("deviceName");
            return this;
        }

        public Builder deviceTag(String deviceTag) {
            this.deviceTag = deviceTag;
            this.changedFields = changedFields.add("deviceTag");
            return this;
        }

        public Builder deviceType(String deviceType) {
            this.deviceType = deviceType;
            this.changedFields = changedFields.add("deviceType");
            return this;
        }

        public Builder flaggedReasons(List<ManagedAppFlaggedReason> flaggedReasons) {
            this.flaggedReasons = flaggedReasons;
            this.changedFields = changedFields.add("flaggedReasons");
            return this;
        }

        public Builder flaggedReasons(ManagedAppFlaggedReason... flaggedReasons) {
            return flaggedReasons(Arrays.asList(flaggedReasons));
        }

        public Builder flaggedReasonsNextLink(String flaggedReasonsNextLink) {
            this.flaggedReasonsNextLink = flaggedReasonsNextLink;
            this.changedFields = changedFields.add("flaggedReasons");
            return this;
        }

        public Builder lastSyncDateTime(OffsetDateTime lastSyncDateTime) {
            this.lastSyncDateTime = lastSyncDateTime;
            this.changedFields = changedFields.add("lastSyncDateTime");
            return this;
        }

        public Builder managedDeviceId(String managedDeviceId) {
            this.managedDeviceId = managedDeviceId;
            this.changedFields = changedFields.add("managedDeviceId");
            return this;
        }

        public Builder managementSdkVersion(String managementSdkVersion) {
            this.managementSdkVersion = managementSdkVersion;
            this.changedFields = changedFields.add("managementSdkVersion");
            return this;
        }

        public Builder platformVersion(String platformVersion) {
            this.platformVersion = platformVersion;
            this.changedFields = changedFields.add("platformVersion");
            return this;
        }

        public Builder userId(String userId) {
            this.userId = userId;
            this.changedFields = changedFields.add("userId");
            return this;
        }

        public Builder version(String version) {
            this.version = version;
            this.changedFields = changedFields.add("version");
            return this;
        }

        public Builder appliedPolicies(List<ManagedAppPolicy> appliedPolicies) {
            this.appliedPolicies = appliedPolicies;
            this.changedFields = changedFields.add("appliedPolicies");
            return this;
        }

        public Builder appliedPolicies(ManagedAppPolicy... appliedPolicies) {
            return appliedPolicies(Arrays.asList(appliedPolicies));
        }

        public Builder intendedPolicies(List<ManagedAppPolicy> intendedPolicies) {
            this.intendedPolicies = intendedPolicies;
            this.changedFields = changedFields.add("intendedPolicies");
            return this;
        }

        public Builder intendedPolicies(ManagedAppPolicy... intendedPolicies) {
            return intendedPolicies(Arrays.asList(intendedPolicies));
        }

        public Builder operations(List<ManagedAppOperation> operations) {
            this.operations = operations;
            this.changedFields = changedFields.add("operations");
            return this;
        }

        public Builder operations(ManagedAppOperation... operations) {
            return operations(Arrays.asList(operations));
        }

        /**
         * <i>“The patch version for the current android app registration”</i>
         * 
         * @param patchVersion
         *            value of {@code patchVersion} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder patchVersion(String patchVersion) {
            this.patchVersion = patchVersion;
            this.changedFields = changedFields.add("patchVersion");
            return this;
        }

        public AndroidManagedAppRegistration build() {
            AndroidManagedAppRegistration _x = new AndroidManagedAppRegistration();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.androidManagedAppRegistration";
            _x.id = id;
            _x.appIdentifier = appIdentifier;
            _x.applicationVersion = applicationVersion;
            _x.azureADDeviceId = azureADDeviceId;
            _x.createdDateTime = createdDateTime;
            _x.deviceManufacturer = deviceManufacturer;
            _x.deviceModel = deviceModel;
            _x.deviceName = deviceName;
            _x.deviceTag = deviceTag;
            _x.deviceType = deviceType;
            _x.flaggedReasons = flaggedReasons;
            _x.flaggedReasonsNextLink = flaggedReasonsNextLink;
            _x.lastSyncDateTime = lastSyncDateTime;
            _x.managedDeviceId = managedDeviceId;
            _x.managementSdkVersion = managementSdkVersion;
            _x.platformVersion = platformVersion;
            _x.userId = userId;
            _x.version = version;
            _x.appliedPolicies = appliedPolicies;
            _x.intendedPolicies = intendedPolicies;
            _x.operations = operations;
            _x.patchVersion = patchVersion;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    /**
     * <i>“The patch version for the current android app registration”</i>
     * 
     * @return property patchVersion
     */
    @Property(name="patchVersion")
    @JsonIgnore
    public Optional<String> getPatchVersion() {
        return Optional.ofNullable(patchVersion);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code patchVersion}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“The patch version for the current android app registration”</i>
     * 
     * @param patchVersion
     *            new value of {@code patchVersion} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code patchVersion} field changed
     */
    public AndroidManagedAppRegistration withPatchVersion(String patchVersion) {
        AndroidManagedAppRegistration _x = _copy();
        _x.changedFields = changedFields.add("patchVersion");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.androidManagedAppRegistration");
        _x.patchVersion = patchVersion;
        return _x;
    }

    public AndroidManagedAppRegistration withUnmappedField(String name, Object value) {
        AndroidManagedAppRegistration _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AndroidManagedAppRegistration patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        AndroidManagedAppRegistration _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AndroidManagedAppRegistration put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        AndroidManagedAppRegistration _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private AndroidManagedAppRegistration _copy() {
        AndroidManagedAppRegistration _x = new AndroidManagedAppRegistration();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.appIdentifier = appIdentifier;
        _x.applicationVersion = applicationVersion;
        _x.azureADDeviceId = azureADDeviceId;
        _x.createdDateTime = createdDateTime;
        _x.deviceManufacturer = deviceManufacturer;
        _x.deviceModel = deviceModel;
        _x.deviceName = deviceName;
        _x.deviceTag = deviceTag;
        _x.deviceType = deviceType;
        _x.flaggedReasons = flaggedReasons;
        _x.lastSyncDateTime = lastSyncDateTime;
        _x.managedDeviceId = managedDeviceId;
        _x.managementSdkVersion = managementSdkVersion;
        _x.platformVersion = platformVersion;
        _x.userId = userId;
        _x.version = version;
        _x.appliedPolicies = appliedPolicies;
        _x.intendedPolicies = intendedPolicies;
        _x.operations = operations;
        _x.patchVersion = patchVersion;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AndroidManagedAppRegistration[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("appIdentifier=");
        b.append(this.appIdentifier);
        b.append(", ");
        b.append("applicationVersion=");
        b.append(this.applicationVersion);
        b.append(", ");
        b.append("azureADDeviceId=");
        b.append(this.azureADDeviceId);
        b.append(", ");
        b.append("createdDateTime=");
        b.append(this.createdDateTime);
        b.append(", ");
        b.append("deviceManufacturer=");
        b.append(this.deviceManufacturer);
        b.append(", ");
        b.append("deviceModel=");
        b.append(this.deviceModel);
        b.append(", ");
        b.append("deviceName=");
        b.append(this.deviceName);
        b.append(", ");
        b.append("deviceTag=");
        b.append(this.deviceTag);
        b.append(", ");
        b.append("deviceType=");
        b.append(this.deviceType);
        b.append(", ");
        b.append("flaggedReasons=");
        b.append(this.flaggedReasons);
        b.append(", ");
        b.append("lastSyncDateTime=");
        b.append(this.lastSyncDateTime);
        b.append(", ");
        b.append("managedDeviceId=");
        b.append(this.managedDeviceId);
        b.append(", ");
        b.append("managementSdkVersion=");
        b.append(this.managementSdkVersion);
        b.append(", ");
        b.append("platformVersion=");
        b.append(this.platformVersion);
        b.append(", ");
        b.append("userId=");
        b.append(this.userId);
        b.append(", ");
        b.append("version=");
        b.append(this.version);
        b.append(", ");
        b.append("appliedPolicies=");
        b.append(this.appliedPolicies);
        b.append(", ");
        b.append("intendedPolicies=");
        b.append(this.intendedPolicies);
        b.append(", ");
        b.append("operations=");
        b.append(this.operations);
        b.append(", ");
        b.append("patchVersion=");
        b.append(this.patchVersion);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
